
from .flow import safe_self_execute
from .logging import get_printer, get_global_setting, get_global_settings, set_global_setting
from .os import create_dir, crawl, spawn_path_options, load_yaml, save_yaml
from .typing import primitives
from .timing import get_now
from .containers import deep_get, Simple_Child, Proper_Child
from .logic import sort_by, resolve_order, toposort




import os
from yaml import safe_load
from setuptools import setup

with open('.fig.yaml','r') as f:
      info = safe_load(f)

if 'readme' in info:
      with open(info['readme'], 'r') as f:
            lines = f.readlines()
      
      readme = []
      valid = False
      for line in lines:
            if valid:
                  if 'end-setup-marker-do-not-remove' in line:
                        valid = False
                  else:
                        readme.append(line)
            elif 'setup-marker-do-not-remove' in line:
                  valid = True
      
      README = '\n'.join(readme)
else:
      README = ''

setup(name=info.get('name', None),
      version=info.get('version', None),
      description=info.get('description', None),
      long_description=README,
      url=info.get('url', None),
      author=info.get('author', None),
      author_email=info.get('author_email', None),
      license=info.get('license', None),
      packages=info.get('packages', [info['name']]),
      entry_points=info.get('entry_points', {}),
      install_requires=info.get('install_requires', []),
      zip_safe=info.get('zip_safe', False),
      )